@@ -35,10 +35,12 @@ Lum::Model::SizeTRef calcTrigoMode=new Lum::Model::SizeT(1);
 
 Alternative::Alternative(const std::wstring& name,
                          const std::wstring& symbol,
-                         const std::wstring& factor)
+                         const std::wstring& from,
+                         const std::wstring& to)
  : name(name),
    symbol(symbol),
-   factor(factor)
+   from(from),
+   to(to)
 {
   // no code
 }
@@ -48,9 +50,19 @@ std::wstring Alternative::GetName() const
   return name;
 }
 
-std::wstring Alternative::GetFactor() const
+std::wstring Alternative::GetSymbol() const
 {
-  return factor;
+  return symbol;
+}
+
+std::wstring Alternative::GetFrom() const
+{
+  return from;
+}
+
+std::wstring Alternative::GetTo() const
+{
+  return to;
 }
 
 Unit::Unit(const std::wstring& type)
@@ -260,16 +272,18 @@ bool LoadData(std::list<ConfigPlugin*>& plugins)
         if (node->GetName()==L"alternative") {
           std::wstring name;
           std::wstring symbol;
-          std::wstring factor;
+          std::wstring from;
+          std::wstring to;
 
           if (!(node->GetAttribute(L"name",name) &&
                 node->GetAttribute(L"symbol",symbol) &&
-                node->GetAttribute(L"factor",factor))) {
-            std::cerr << "type/alternative node is missing attribute 'name', 'symbol' or 'factor'" << std::endl;
+                node->GetAttribute(L"from",from) &&
+                node->GetAttribute(L"to",to))) {
+            std::cerr << "type/alternative node is missing attribute 'name', 'symbol', 'from' or 'to'" << std::endl;
             break;
           }
 
-          unit->AddAlternative(new Alternative(name,symbol,factor));
+          unit->AddAlternative(new Alternative(name,symbol,from,to));
         }
       }
 
