@@ -19,8 +19,9 @@
 
 #include "Parser.h"
 
-#include <locale.h>
-#include <iostream>
+#include <clocale>
+#include <cstdio>
+
 /**
   The mathematical functions of the parser. They directly work on the stack.
 */
