@@ -564,6 +564,11 @@ void Plot::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
   Lum::Component::Resync(model,msg);
 }
 
+void Plot::LoadData()
+{
+  // no code
+}
+
 void Plot::LoadConfig(Lum::Config::Node *top)
 {
   for (Lum::Config::Node::NodeList::const_iterator iter=top->GetChildren().begin();
